
.. euler_1d_wcblast:

Euler equations in 1d -- Woodward-Colella blast wave problem
------------------------------------------------------------

The Woodward-Colella interacting blast wave problem consists of the
one-dimensional Euler equations of compressible gas dynamics together with
initial data containing two discontinuities in pressure that lead to strong
shock waves that interact with one another.

This code is based on the discussion in Example 15.1 of 
`Finite Volume Methods for Hyperbolic Problems
<http://www.clawpack.org/book.html>`_ by R. J. LeVeque.
Figures 15.5 and 15.6 show the solution at time t = 0.038 as computed with
various methods.

After running this code and creating plots via "make .plots", you
should be able to view the plots in _plots/_PlotIndex.html.

